@echo off
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::
:: Program Flash
:: Generate an image file and program it into flash
:: 
:: program_flash.bat <IP> <MAC> <Configuration> <PrmFile> [DEV MAC]
:: 
::
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::

:: Cleanup
del /Q tmp\OSEC.HEX >NUL 2>&1
del /Q tmp\MSEC.HEX >NUL 2>&1
del /Q tmp\all.inf >NUL 2>&1

if "%1"=="-?" goto USAGE
if "%1"=="-h" goto USAGE
IF .%1==. goto USAGE
IF .%2==. goto ERROR
IF .%3==. goto ERROR
IF .%4==. goto ERROR

::
:: Construct an auto activate inf file
::
if not exist %4 goto FILE_ERROR
echo auto_activate=1 > tmp\all.inf
more %4 >> tmp\all.inf
set prm_path=tmp\all.inf

:: set environment
call setenv.bat

:: Make OEM section with new MAC address

%mkprm% -m -f %prm_path% > tmp\MSEC.HEX
if %ERRORLEVEL% lss 0 goto PRMFAIL
%mkprm% -M %2 -o -f %prm_path% > tmp\OSEC.HEX
if %ERRORLEVEL% lss 0 goto PRMFAIL
%mkprm% -0 -f %prm_path% > tmp\0.HEX
if %ERRORLEVEL% lss 0 goto PRMFAIL
%mkprm% -1 -f %prm_path% > tmp\1.HEX
if %ERRORLEVEL% lss 0 goto PRMFAIL
%mkprm% -2 -f %prm_path% > tmp\2.HEX
if %ERRORLEVEL% lss 0 goto PRMFAIL

:: select hardware configuration vector file
IF .%3==.phone1 set hw_cfg=%HWPATH%\config1.txt
IF .%3==.phone2 set hw_cfg=%HWPATH%\config2.txt
IF .%3==.phone3 set hw_cfg=%HWPATH%\config3.txt
IF .%3==.phone4 set hw_cfg=%HWPATH%\config4.txt
IF .%3==.phone5 set hw_cfg=%HWPATH%\config5.txt
IF .%3==.phone6 set hw_cfg=%HWPATH%\config6.txt
IF .%3==.coax1 set  hw_cfg=%HWPATH%\config7.txt
IF .%3==.coax2 set  hw_cfg=%HWPATH%\config12.txt

:: Attempt to query device MAC address if non was provided
:: if we fail we will assume ROM default
:: address, i.e. 00-C5-D9-00-00-00
set device_mac_@@=%5
if NOT .%5==. (goto NOQUERY)

call query_address.bat %1 > !!@@##$$##@@!!
if %ERRORLEVEL%==0 (
	set /p device_mac_@@=< !!@@##$$##@@!!	
) else (
	set device_mac_@@=00-C5-D9-00-00-00
)
del !!@@##$$##@@!!

:NOQUERY

:: Build Firmware image file
%mkconf% -F -Y -o tmp\OSEC.HEX -m tmp\MSEC.HEX -0 tmp\0.HEX -1 tmp\1.HEX -2 tmp\2.HEX -x %xpath%\x1.hex -x %xpath%\x2.hex -x %xpath%\x3.hex -x %xpath%\x4.hex -i %hw_cfg% -f flash.bin
if %ERRORLEVEL% lss 0 goto MKFAIL

:: Program image file to FLASH
%loader% -M %device_mac_@@% -a %1 -s scr\program_flash.txt
if %ERRORLEVEL% lss 0 goto PROGFAIL
set RUN_RESULT=1
goto END

:ERROR
echo ERROR - Invalid input!
set RUN_RESULT=-101
goto USAGE

:PRMFAIL
@echo Failed to process parameters
set RUN_RESULT=-102
goto END

:FILE_ERROR
@echo ERROR - File %4 could not be found
set RUN_RESULT=-103
goto END

:USAGE
@echo.
@echo Usage: "program_flash.bat <IP> <MAC> <Configuration> <PrmFile> [DEV MAC]"
@echo.
@echo   IP      - IP address of NIC to use e.g: 192.168.2.1
@echo   MAC     - Mac address to program into device e.g: 00-C5-D9-00-00-22
@echo   ConfID  - Hardware configuration 
@echo             Available Cfg: phone1, phone2, phone3, phone4, phone5, phone6, coax1, coax2 
@echo   PrmFile - Full path to prm file (default: ..\fwtool\prm.inf)
@echo   DEV_MAC	- (Optional) Device current MAC address. If omitted the script will attempt
@echo.			  to query device MAC - if fails a default one is used: 00-C5-D9-00-00-00
@echo.
@echo.
set RUN_RESULT=-101
goto END

:MKFAIL
@echo Image generation failed!
set RUN_RESULT=-104
goto END

:PROGFAIL
@echo Flash programming failed %ERRORLEVEL%
set RUN_RESULT=-105
goto END

:END
:: Cleanup
del /Q tmp\OSEC.HEX >NUL 2>&1
del /Q tmp\MSEC.HEX >NUL 2>&1
del /Q tmp\prm.inf >NUL 2>&1
del /Q tmp\all.inf >NUL 2>&1
del /Q tmp\0.HEX >NUL 2>&1
del /Q tmp\1.HEX >NUL 2>&1
del /Q tmp\2.HEX >NUL 2>&1
del /Q flash.bin >NUL 2>&1

exit %RUN_RESULT%